@@ -424,8 +424,8 @@ class MaoboApp(QApplication):
             self.unread_notifiers[args[0]+":t"+args[1]] = 0
         
             # clean unread counts
-            #self.unread_updaters[str(self.accounts[int(args[0])]["id"])].initialize(self.accounts[int(args[0])]["id"], Utils.TIMELINE_TYPE_DEUNREAD, optype=int(args[1])) 
-            #self.unread_updaters[str(self.accounts[int(args[0])]["id"])].start()
+            self.unread_updaters[str(self.accounts[int(args[0])]["id"])].initialize(self.accounts[int(args[0])]["id"], Utils.TIMELINE_TYPE_DEUNREAD, optype=int(args[1])) 
+            self.unread_updaters[str(self.accounts[int(args[0])]["id"])].start()
         else:    
             print "Not support method: " + method
             return
