@@ -67,6 +67,15 @@ class API(object):
         require_auth = True
     )
     
+    """ statuses/reset_count """
+    reset_count = bind_api(
+        path = '/statuses/reset_count.json',
+        method = 'POST',
+        payload_type = 'comments',
+        allowed_param = ['type'],
+        require_auth = True
+    )
+    
     """ statuses/comment_destroy """
     comment_destroy  = bind_api(
         path = '/statuses/comment_destroy/{id}.json',
